@@ -4,10 +4,7 @@ import bpy_types
 import rna_prop_ui
 
 
-class MESH_MT_shape_key_specials(bpy_types.Menu, bpy_types._GenericUI):
-    COMPAT_ENGINES = None
-    ''' '''
-
+class MESH_MT_shape_key_context_menu(bpy_types.Menu, bpy_types._GenericUI):
     bl_label = None
     ''' '''
 
@@ -29,7 +26,19 @@ class MESH_MT_shape_key_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw(self, context):
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, _context):
         ''' 
 
         '''
@@ -41,7 +50,7 @@ class MESH_MT_shape_key_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_preset(self, context):
+    def draw_preset(self, _context):
         ''' 
 
         '''
@@ -77,6 +86,12 @@ class MESH_MT_shape_key_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -120,7 +135,7 @@ class MESH_MT_shape_key_specials(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
     def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
+                  filter_ext, filter_path, display_name, add_operator):
         ''' 
 
         '''
@@ -132,12 +147,24 @@ class MESH_MT_shape_key_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -163,10 +190,7 @@ class MESH_MT_shape_key_specials(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
 
-class MESH_MT_vertex_group_specials(bpy_types.Menu, bpy_types._GenericUI):
-    COMPAT_ENGINES = None
-    ''' '''
-
+class MESH_MT_vertex_group_context_menu(bpy_types.Menu, bpy_types._GenericUI):
     bl_label = None
     ''' '''
 
@@ -188,7 +212,19 @@ class MESH_MT_vertex_group_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw(self, context):
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, _context):
         ''' 
 
         '''
@@ -200,7 +236,7 @@ class MESH_MT_vertex_group_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_preset(self, context):
+    def draw_preset(self, _context):
         ''' 
 
         '''
@@ -236,6 +272,12 @@ class MESH_MT_vertex_group_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -279,7 +321,7 @@ class MESH_MT_vertex_group_specials(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
     def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
+                  filter_ext, filter_path, display_name, add_operator):
         ''' 
 
         '''
@@ -291,12 +333,189 @@ class MESH_MT_vertex_group_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+class MESH_UL_fmaps(bpy_types.UIList, bpy_types._GenericUI):
+    bl_rna = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw_item(self, _context, layout, _data, item, icon, _active_data,
+                  _active_propname, _index):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -341,8 +560,20 @@ class MESH_UL_shape_keys(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_item(self, context, layout, data, item, icon, active_data,
-                  active_propname, index):
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw_item(self, _context, layout, _data, item, icon, active_data,
+                  _active_propname, index):
         ''' 
 
         '''
@@ -378,6 +609,12 @@ class MESH_UL_shape_keys(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -426,12 +663,24 @@ class MESH_UL_shape_keys(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -457,7 +706,7 @@ class MESH_UL_shape_keys(bpy_types.UIList, bpy_types._GenericUI):
         pass
 
 
-class MESH_UL_uvmaps_vcols(bpy_types.UIList, bpy_types._GenericUI):
+class MESH_UL_uvmaps(bpy_types.UIList, bpy_types._GenericUI):
     bl_rna = None
     ''' '''
 
@@ -476,8 +725,20 @@ class MESH_UL_uvmaps_vcols(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_item(self, context, layout, data, item, icon, active_data,
-                  active_propname, index):
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw_item(self, _context, layout, _data, item, icon, _active_data,
+                  _active_propname, _index):
         ''' 
 
         '''
@@ -513,6 +774,12 @@ class MESH_UL_uvmaps_vcols(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -561,12 +828,189 @@ class MESH_UL_uvmaps_vcols(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+class MESH_UL_vcols(bpy_types.UIList, bpy_types._GenericUI):
+    bl_rna = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw_item(self, _context, layout, _data, item, icon, _active_data,
+                  _active_propname, _index):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -611,8 +1055,20 @@ class MESH_UL_vgroups(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_item(self, context, layout, data, item, icon, active_data,
-                  active_propname, index):
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw_item(self, _context, layout, _data, item, icon, _active_data_,
+                  _active_propname, _index):
         ''' 
 
         '''
@@ -648,6 +1104,12 @@ class MESH_UL_vgroups(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -696,12 +1158,24 @@ class MESH_UL_vgroups(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -782,6 +1256,18 @@ class DATA_PT_context_mesh(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -818,6 +1304,12 @@ class DATA_PT_context_mesh(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -872,12 +1364,24 @@ class DATA_PT_context_mesh(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -917,6 +1421,9 @@ class DATA_PT_custom_props_mesh(MeshButtonsPanel, rna_prop_ui.PropertyPanel,
     bl_options = None
     ''' '''
 
+    bl_order = None
+    ''' '''
+
     bl_region_type = None
     ''' '''
 
@@ -941,6 +1448,18 @@ class DATA_PT_custom_props_mesh(MeshButtonsPanel, rna_prop_ui.PropertyPanel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -977,6 +1496,12 @@ class DATA_PT_custom_props_mesh(MeshButtonsPanel, rna_prop_ui.PropertyPanel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1031,12 +1556,24 @@ class DATA_PT_custom_props_mesh(MeshButtonsPanel, rna_prop_ui.PropertyPanel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1100,6 +1637,18 @@ class DATA_PT_customdata(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -1136,6 +1685,12 @@ class DATA_PT_customdata(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1190,12 +1745,213 @@ class DATA_PT_customdata(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+class DATA_PT_face_maps(MeshButtonsPanel, bpy_types.Panel,
+                        bpy_types._GenericUI):
+    COMPAT_ENGINES = None
+    ''' '''
+
+    bl_context = None
+    ''' '''
+
+    bl_label = None
+    ''' '''
+
+    bl_options = None
+    ''' '''
+
+    bl_region_type = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    bl_space_type = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def poll(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1231,6 +1987,9 @@ class DATA_PT_normals(MeshButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
     bl_label = None
     ''' '''
 
+    bl_options = None
+    ''' '''
+
     bl_region_type = None
     ''' '''
 
@@ -1255,6 +2014,18 @@ class DATA_PT_normals(MeshButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -1291,6 +2062,12 @@ class DATA_PT_normals(MeshButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1345,12 +2122,407 @@ class DATA_PT_normals(MeshButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+class DATA_PT_normals_auto_smooth(MeshButtonsPanel, bpy_types.Panel,
+                                  bpy_types._GenericUI):
+    COMPAT_ENGINES = None
+    ''' '''
+
+    bl_context = None
+    ''' '''
+
+    bl_label = None
+    ''' '''
+
+    bl_parent_id = None
+    ''' '''
+
+    bl_region_type = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    bl_space_type = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def draw_header(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def poll(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+class DATA_PT_remesh(MeshButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
+    COMPAT_ENGINES = None
+    ''' '''
+
+    bl_context = None
+    ''' '''
+
+    bl_label = None
+    ''' '''
+
+    bl_options = None
+    ''' '''
+
+    bl_region_type = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    bl_space_type = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def poll(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1411,6 +2583,18 @@ class DATA_PT_shape_keys(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -1447,6 +2631,12 @@ class DATA_PT_shape_keys(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1501,12 +2691,24 @@ class DATA_PT_shape_keys(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1570,6 +2772,18 @@ class DATA_PT_texture_space(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -1606,6 +2820,12 @@ class DATA_PT_texture_space(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1660,12 +2880,24 @@ class DATA_PT_texture_space(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1702,6 +2934,9 @@ class DATA_PT_uv_texture(MeshButtonsPanel, bpy_types.Panel,
     bl_label = None
     ''' '''
 
+    bl_options = None
+    ''' '''
+
     bl_region_type = None
     ''' '''
 
@@ -1726,6 +2961,18 @@ class DATA_PT_uv_texture(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -1762,6 +3009,12 @@ class DATA_PT_uv_texture(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1816,12 +3069,24 @@ class DATA_PT_uv_texture(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1858,6 +3123,9 @@ class DATA_PT_vertex_colors(MeshButtonsPanel, bpy_types.Panel,
     bl_label = None
     ''' '''
 
+    bl_options = None
+    ''' '''
+
     bl_region_type = None
     ''' '''
 
@@ -1882,6 +3150,18 @@ class DATA_PT_vertex_colors(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -1918,6 +3198,12 @@ class DATA_PT_vertex_colors(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1972,12 +3258,24 @@ class DATA_PT_vertex_colors(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -2038,6 +3336,18 @@ class DATA_PT_vertex_groups(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -2074,6 +3384,12 @@ class DATA_PT_vertex_groups(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -2128,12 +3444,24 @@ class DATA_PT_vertex_groups(MeshButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
