@@ -2,8 +2,6 @@ import sys
 import typing
 import bpy_types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class ShaderFxButtonsPanel:
     bl_context = None
@@ -66,12 +64,6 @@ class DATA_PT_shader_fx(ShaderFxButtonsPanel, bpy_types.Panel,
         '''
         pass
 
-    def FX_LIGHT(self, layout, fx):
-        ''' 
-
-        '''
-        pass
-
     def FX_PIXEL(self, layout, fx):
         ''' 
 
