@@ -2,8 +2,6 @@ import sys
 import typing
 import bpy_types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class OUTLINER_HT_header(bpy_types.Header, bpy_types._GenericUI):
     bl_rna = None
@@ -410,6 +408,12 @@ class OUTLINER_MT_collection_new(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def draw_without_context_menu(self, context, layout):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -916,7 +920,7 @@ class OUTLINER_MT_collection_visibility(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
 
-class OUTLINER_MT_context(bpy_types.Menu, bpy_types._GenericUI):
+class OUTLINER_MT_context_menu(bpy_types.Menu, bpy_types._GenericUI):
     bl_label = None
     ''' '''
 
@@ -950,7 +954,7 @@ class OUTLINER_MT_context(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw(self, _context):
+    def draw(self, context):
         ''' 
 
         '''
@@ -1102,7 +1106,7 @@ class OUTLINER_MT_context(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
 
-class OUTLINER_MT_context_view(bpy_types.Menu, bpy_types._GenericUI):
+class OUTLINER_MT_context_menu_view(bpy_types.Menu, bpy_types._GenericUI):
     bl_label = None
     ''' '''
 
