@@ -3,8 +3,6 @@ import typing
 import bl_ui.space_toolsystem_common
 import bpy_types
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class IMAGE_PT_tools_active(
         bl_ui.space_toolsystem_common.ToolSelectPanelHelper, bpy_types.Panel,
@@ -497,6 +495,252 @@ class NODE_PT_tools_active(bl_ui.space_toolsystem_common.ToolSelectPanelHelper,
         pass
 
 
+class SEQUENCER_PT_tools_active(
+        bl_ui.space_toolsystem_common.ToolSelectPanelHelper, bpy_types.Panel,
+        bpy_types._GenericUI):
+    bl_label = None
+    ''' '''
+
+    bl_options = None
+    ''' '''
+
+    bl_region_type = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    bl_space_type = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    keymap_prefix = None
+    ''' '''
+
+    tool_fallback_id = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def draw_active_tool_fallback(self, context, layout, tool,
+                                  is_horizontal_layout):
+        ''' 
+
+        '''
+        pass
+
+    def draw_active_tool_header(self, context, layout, show_tool_name,
+                                tool_key):
+        ''' 
+
+        '''
+        pass
+
+    def draw_cls(self, layout, context, detect_layout, scale_y):
+        ''' 
+
+        '''
+        pass
+
+    def draw_fallback_tool_items(self, layout, context):
+        ''' 
+
+        '''
+        pass
+
+    def draw_fallback_tool_items_for_pie_menu(self, layout, context):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keymap_ui_hierarchy(self, context_mode):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def register(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def tool_active_from_context(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def tools_all(self):
+        ''' 
+
+        '''
+        pass
+
+    def tools_from_context(self, context, mode):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
 class VIEW3D_PT_tools_active(
         bl_ui.space_toolsystem_common.ToolSelectPanelHelper, bpy_types.Panel,
         bpy_types._GenericUI):
@@ -899,6 +1143,15 @@ class _defs_gpencil_edit:
     tosphere = None
     ''' '''
 
+    transform_fill = None
+    ''' '''
+
+    def is_segment(self, context):
+        ''' 
+
+        '''
+        pass
+
 
 class _defs_gpencil_paint:
     arc = None
@@ -946,6 +1199,20 @@ class _defs_gpencil_sculpt:
         pass
 
 
+class _defs_gpencil_vertex:
+    def generate_from_brushes(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def poll_select_mask(self, context):
+        ''' 
+
+        '''
+        pass
+
+
 class _defs_gpencil_weight:
     def generate_from_brushes(self, context):
         ''' 
@@ -1062,6 +1329,22 @@ class _defs_sculpt:
         pass
 
 
+class _defs_sequencer_generic:
+    blade = None
+    ''' '''
+
+    sample = None
+    ''' '''
+
+
+class _defs_sequencer_select:
+    box = None
+    ''' '''
+
+    select = None
+    ''' '''
+
+
 class _defs_texture_paint:
     def generate_from_brushes(self, context):
         ''' 
