@@ -3,8 +3,6 @@ import typing
 import bpy.types
 import mathutils
 
-GenericType = typing.TypeVar("GenericType")
-
 
 class BMDeformVert:
     def clear(self):
@@ -23,26 +21,26 @@ class BMDeformVert:
         '''
         pass
 
-    def items(self) -> typing.List:
+    def items(self) -> list:
         ''' Return (group, weight) pairs for this vertex (matching pythons dict.items() functionality).
 
-        :rtype: typing.List
+        :rtype: list
         :return: (key, value) pairs for each deform weight of this vertex.
         '''
         pass
 
-    def keys(self) -> typing.List[int]:
+    def keys(self) -> list:
         ''' Return the group indices used by this vertex (matching pythons dict.keys() functionality).
 
-        :rtype: typing.List[int]
+        :rtype: list
         :return: the deform group this vertex uses
         '''
         pass
 
-    def values(self) -> typing.List[float]:
+    def values(self) -> list:
         ''' Return the weights of the deform vertex (matching pythons dict.values() functionality).
 
-        :rtype: typing.List[float]
+        :rtype: list
         :return: The weights that influence this vertex
         '''
         pass
@@ -237,7 +235,7 @@ class BMEdgeSeq:
 
         :param verts: Sequence of verts.
         :type verts: 'BMVert'
-        :param fallback:  Return this value if nothing is found.
+        :param fallback: 
         :type fallback: 
         :rtype: 'BMEdge'
         :return: The edge found or None
@@ -250,14 +248,13 @@ class BMEdgeSeq:
         '''
         pass
 
-    def new(self, verts: 'BMVert',
-            example: typing.Optional['BMEdge'] = None) -> 'BMEdge':
+    def new(self, verts: 'BMVert', example: 'BMEdge' = None) -> 'BMEdge':
         ''' Create a new edge from a given pair of verts.
 
         :param verts: Vertex pair.
         :type verts: 'BMVert'
         :param example: Existing edge to initialize settings (optional argument).
-        :type example: typing.Optional['BMEdge']
+        :type example: 'BMEdge'
         :rtype: 'BMEdge'
         :return: The newly created edge.
         '''
@@ -285,10 +282,10 @@ class BMEditSelIter:
 
 
 class BMEditSelSeq:
-    active: 'BMVert' = None
+    active: typing.Union['BMVert', 'BMEdge', 'BMFace'] = None
     ''' The last selected element or None (read-only).
 
-    :type: 'BMVert'
+    :type: typing.Union['BMVert', 'BMEdge', 'BMFace']
     '''
 
     def add(self, element):
@@ -556,7 +553,7 @@ class BMFaceSeq:
 
         :param verts: Sequence of verts.
         :type verts: 'BMVert'
-        :param fallback:  Return this value if nothing is found.
+        :param fallback: 
         :type fallback: 
         :rtype: 'BMFace'
         :return: The face found or None
@@ -569,14 +566,13 @@ class BMFaceSeq:
         '''
         pass
 
-    def new(self, verts: 'BMVert',
-            example: typing.Optional['BMFace'] = None) -> 'BMFace':
+    def new(self, verts: 'BMVert', example: 'BMFace' = None) -> 'BMFace':
         ''' Create a new face from a given set of verts.
 
         :param verts: Sequence of 3 or more verts.
         :type verts: 'BMVert'
         :param example: Existing face to initialize settings (optional argument).
-        :type example: typing.Optional['BMFace']
+        :type example: 'BMFace'
         :rtype: 'BMFace'
         :return: The newly created face.
         '''
@@ -736,18 +732,18 @@ class BMLayerCollection:
         '''
         pass
 
-    def items(self) -> typing.List:
+    def items(self) -> list:
         ''' Return the identifiers of collection members (matching pythons dict.items() functionality).
 
-        :rtype: typing.List
+        :rtype: list
         :return: (key, value) pairs for each member of this collection.
         '''
         pass
 
-    def keys(self) -> typing.List[str]:
+    def keys(self) -> list:
         ''' Return the identifiers of collection members (matching pythons dict.keys() functionality).
 
-        :rtype: typing.List[str]
+        :rtype: list
         :return: the identifiers for each member of this collection.
         '''
         pass
@@ -770,10 +766,10 @@ class BMLayerCollection:
         '''
         pass
 
-    def values(self) -> typing.List:
+    def values(self) -> list:
         ''' Return the values of collection (matching pythons dict.values() functionality).
 
-        :rtype: typing.List
+        :rtype: list
         :return: the members of this collection.
         '''
         pass
@@ -800,9 +796,9 @@ class BMLayerItem:
     def copy_from(self, other):
         ''' Return a copy of the layer
 
-        :param other:  Another layer to copy from.
+        :param other: 
         :type other: 
-        :param other:  BMLayerItem
+        :param other: 
         :type other: 
         '''
         pass
@@ -916,16 +912,16 @@ class BMLoop:
 
     def copy_from_face_interp(self,
                               face: 'BMFace',
-                              vert: typing.Optional[bool] = True,
-                              multires: typing.Optional[bool] = True):
+                              vert: bool = True,
+                              multires: bool = True):
         ''' Interpolate the customdata from a face onto this loop (the loops vert should overlap the face).
 
         :param face: The face to interpolate data from.
         :type face: 'BMFace'
         :param vert: When enabled, interpolate the loops vertex data (optional).
-        :type vert: typing.Optional[bool]
+        :type vert: bool
         :param multires: When enabled, interpolate the loops multires data (optional).
-        :type multires: typing.Optional[bool]
+        :type multires: bool
         '''
         pass
 
@@ -951,12 +947,6 @@ class BMLoopUV:
     :type: bool
     '''
 
-    select_edge: bool = None
-    ''' UV edge select state.
-
-    :type: bool
-    '''
-
     uv: 'mathutils.Vector' = None
     ''' Loops UV (as a 2D Vector).
 
@@ -1128,13 +1118,12 @@ class BMVertSeq:
         '''
         pass
 
-    def new(self,
-            co: typing.Optional[typing.Tuple[float]] = (0.0, 0.0, 0.0),
+    def new(self, co: float = (0.0, 0.0, 0.0),
             example: 'BMVert' = None) -> 'BMVert':
         ''' Create a new vertex.
 
         :param co: The initial location of the vertex (optional argument).
-        :type co: typing.Optional[typing.Tuple[float]]
+        :type co: float
         :param example: Existing vert to initialize settings.
         :type example: 'BMVert'
         :rtype: 'BMVert'
@@ -1163,16 +1152,16 @@ class BMesh:
     ''' The BMesh data structure
     '''
 
-    edges: typing.Union[typing.List['BMEdg'], 'BMEdgeSeq'] = None
+    edges: typing.Union[typing.List['BMEdge'], 'BMEdgeSeq'] = None
     ''' This meshes edge sequence (read-only).
 
-    :type: typing.Union[typing.List['BMEdg'], 'BMEdgeSeq']
+    :type: typing.Union[typing.List['BMEdge'], 'BMEdgeSeq']
     '''
 
-    faces: typing.Union[typing.List['BMFac'], 'BMFaceSeq'] = None
+    faces: typing.Union[typing.List['BMFace'], 'BMFaceSeq'] = None
     ''' This meshes face sequence (read-only).
 
-    :type: typing.Union[typing.List['BMFac'], 'BMFaceSeq']
+    :type: typing.Union[typing.List['BMFace'], 'BMFaceSeq']
     '''
 
     is_valid: bool = None
@@ -1193,17 +1182,16 @@ class BMesh:
     :type: typing.Union[typing.List['BMLoop'], 'BMLoopSeq']
     '''
 
-    select_history: typing.Union[typing.
-                                 List['BMEditSel'], 'BMEditSelSeq'] = None
+    select_history: 'BMEditSelSeq' = None
     ''' Sequence of selected items (the last is displayed as active).
 
-    :type: typing.Union[typing.List['BMEditSel'], 'BMEditSelSeq']
+    :type: 'BMEditSelSeq'
     '''
 
-    select_mode: typing.Set = None
+    select_mode: set = None
     ''' The selection mode, values can be {'VERT', 'EDGE', 'FACE'}, can't be assigned an empty set.
 
-    :type: typing.Set
+    :type: set
     '''
 
     verts: typing.Union[typing.List['BMVert'], 'BMVertSeq'] = None
@@ -1313,12 +1301,12 @@ class BMesh:
         '''
         pass
 
-    def transform(self, matrix: 'mathutils.Matrix', filter: typing.Set = None):
+    def transform(self, matrix: 'mathutils.Matrix', filter: set = None):
         ''' Transform the mesh (optionally filtering flagged data only).
 
         :param matrix: transform matrix.
         :type matrix: 'mathutils.Matrix'
         :param filter: set of values in ('SELECT', 'HIDE', 'SEAM', 'SMOOTH', 'TAG').
-        :type filter: typing.Set
+        :type filter: set
         '''
         pass
