@@ -4,13 +4,12 @@ import bpy.types
 
 from . import types
 from . import ops
-from . import utils
 from . import app
 from . import props
 from . import path
-
-GenericType = typing.TypeVar("GenericType")
-context: 'bpy.types.Context' = None
+from . import utils
+from . import context
+from . import msgbus
 
 data: 'bpy.types.BlendData' = None
 ''' Access to Blender's internal data
