@@ -1,25 +1,24 @@
 import sys
 import typing
 from . import handlers
+from . import translations
 from . import timers
 from . import icons
-from . import translations
 
-GenericType = typing.TypeVar("GenericType")
 alembic = None
 ''' constant value bpy.app.alembic(supported=True, version=(1, 7, 12), version_string=' 1, 7, 12')
 '''
 
 autoexec_fail = None
-''' Undocumented contribute <https://developer.blender.org/T51061>
+''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 '''
 
 autoexec_fail_message = None
-''' Undocumented contribute <https://developer.blender.org/T51061>
+''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 '''
 
 autoexec_fail_quiet = None
-''' Undocumented contribute <https://developer.blender.org/T51061>
+''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 '''
 
 background = None
@@ -71,7 +70,7 @@ build_linkflags = None
 '''
 
 build_options = None
-''' constant value bpy.app.build_options(bullet=True, codec_avi=True, codec_ffmpeg=True, codec_sndfile=True, compositor=True, cycles=True, cycles_osl=True, freestyle=True, image_cineon=True, image_dds=True, image_hdr=True, image_openexr=True, image_openjpeg=True, image_tiff=True, input_ndof=True, audaspace=True, international=True, openal=True, opensubdiv=True, sdl=True, sdl_dynload=True, jack=True, libmv=True, mod_oceansim=True, mod_remesh=True, collada=True, opencolorio=True, openmp=True, openvdb=True, alembic=True, ...)
+''' constant value bpy.app.build_options(bullet=True, codec_avi=True, codec_ffmpeg=True, codec_sndfile=True, compositor=True, cycles=True, cycles_osl=True, freestyle=True, image_cineon=True, image_dds=True, image_hdr=True, image_openexr=True, image_openjpeg=True, image_tiff=True, input_ndof=True, audaspace=True, international=True, openal=True, opensubdiv=True, sdl=True, sdl_dynload=True, jack=True, libmv=True, mod_oceansim=True, mod_remesh=True, collada=True, opencolorio=True, openmp=False, openvdb=True, alembic=True, ...)
 '''
 
 build_platform = None
@@ -235,11 +234,11 @@ use_userpref_skip_save_on_exit = None
 '''
 
 version = None
-''' The Blender version as a tuple of 3 numbers. eg. (2, 50, 11)
+''' The Blender version as a tuple of 3 numbers. eg. (2, 83, 1)
 '''
 
 version_char = None
-''' The Blender version character (for minor releases)
+''' Deprecated, always an empty string
 '''
 
 version_cycle = None
