@@ -1,16 +1,8 @@
 import sys
 import typing
-import bpy.types
-
-GenericType = typing.TypeVar("GenericType")
 
 
-def open(override_context: typing.Union[typing.
-                                        Dict, 'bpy.types.Context'] = None,
-         execution_context: typing.Union[str, int] = None,
-         undo: bool = None,
-         *,
-         filepath: str = "",
+def open(filepath: str = "",
          hide_props_region: bool = True,
          check_existing: bool = True,
          filter_blender: bool = False,
@@ -26,6 +18,7 @@ def open(override_context: typing.Union[typing.
          filter_collada: bool = False,
          filter_alembic: bool = True,
          filter_usd: bool = False,
+         filter_volume: bool = False,
          filter_folder: bool = True,
          filter_blenlib: bool = False,
          filemode: int = 8,
@@ -33,9 +26,6 @@ def open(override_context: typing.Union[typing.
          sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
     ''' Load a cache file
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Path to file
     :type filepath: str
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
@@ -68,6 +58,8 @@ def open(override_context: typing.Union[typing.
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_volume: Filter OpenVDB volume files
+    :type filter_volume: bool
     :param filter_folder: Filter folders
     :type filter_folder: bool
     :param filter_blenlib: Filter Blender IDs
@@ -83,15 +75,9 @@ def open(override_context: typing.Union[typing.
     pass
 
 
-def reload(override_context: typing.Union[typing.
-                                          Dict, 'bpy.types.Context'] = None,
-           execution_context: typing.Union[str, int] = None,
-           undo: bool = None):
+def reload():
     ''' Update objects paths list with new data from the archive
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     '''
 
     pass
