@@ -1,16 +1,8 @@
 import sys
 import typing
-import bpy.types
-
-GenericType = typing.TypeVar("GenericType")
 
 
-def fbx(override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        filepath: str = "",
+def fbx(filepath: str = "",
         check_existing: bool = True,
         filter_glob: str = "*.fbx",
         use_selection: bool = False,
@@ -50,9 +42,6 @@ def fbx(override_context: typing.Union[typing.
         axis_up: typing.Union[str, int] = 'Y'):
     ''' Write a FBX file
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Filepath used for exporting the file
     :type filepath: str
     :param check_existing: Check Existing, Check and warn on overwriting existing files
@@ -79,7 +68,7 @@ def fbx(override_context: typing.Union[typing.
     :type use_mesh_modifiers_render: bool
     :param mesh_smooth_type: Smoothing, Export smoothing information (prefer 'Normals Only' option if your target importer understand split normals) * OFF Normals Only, Export only normals instead of writing edge or face smoothing data. * FACE Face, Write face smoothing. * EDGE Edge, Write edge smoothing.
     :type mesh_smooth_type: typing.Union[str, int]
-    :param use_subsurf: Export Subdivision Surface, Export the last Catmull-Rom subidivion modifier as FBX subdivision (Does not apply the modifier even if 'Apply Modifiers' is enabled)
+    :param use_subsurf: Export Subdivision Surface, Export the last Catmull-Rom subdivision modifier as FBX subdivision (does not apply the modifier even if 'Apply Modifiers' is enabled)
     :type use_subsurf: bool
     :param use_mesh_edges: Loose Edges, Export loose edges (as two-vertices polygons)
     :type use_mesh_edges: bool
@@ -130,15 +119,10 @@ def fbx(override_context: typing.Union[typing.
     pass
 
 
-def gltf(override_context: typing.Union[typing.
-                                        Dict, 'bpy.types.Context'] = None,
-         execution_context: typing.Union[str, int] = None,
-         undo: bool = None,
-         *,
-         export_format: typing.Union[str, int] = 'GLB',
+def gltf(export_format: typing.Union[str, int] = 'GLB',
          ui_tab: typing.Union[str, int] = 'GENERAL',
          export_copyright: str = "",
-         export_image_format: typing.Union[str, int] = 'NAME',
+         export_image_format: typing.Union[str, int] = 'AUTO',
          export_texture_dir: str = "",
          export_texcoords: bool = True,
          export_normals: bool = True,
@@ -153,6 +137,7 @@ def gltf(override_context: typing.Union[typing.
          export_colors: bool = True,
          export_cameras: bool = False,
          export_selected: bool = False,
+         use_selection: bool = False,
          export_extras: bool = False,
          export_yup: bool = True,
          export_apply: bool = False,
@@ -176,16 +161,13 @@ def gltf(override_context: typing.Union[typing.
          filter_glob: str = "*.glb;*.gltf"):
     ''' Export scene as glTF 2.0 file
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param export_format: Format, Output format and embedding options. Binary is most efficient, but JSON (embedded or separate) may be easier to edit later * GLB glTF Binary (.glb), Exports a single file, with all data packed in binary form. Most efficient and portable, but more difficult to edit later. * GLTF_EMBEDDED glTF Embedded (.gltf), Exports a single file, with all data packed in JSON. Less efficient than binary, but easier to edit later. * GLTF_SEPARATE glTF Separate (.gltf + .bin + textures), Exports multiple files, with separate JSON, binary and texture data. Easiest to edit later.
     :type export_format: typing.Union[str, int]
     :param ui_tab: ui_tab, Export setting categories * GENERAL General, General settings. * MESHES Meshes, Mesh settings. * OBJECTS Objects, Object settings. * ANIMATION Animation, Animation settings.
     :type ui_tab: typing.Union[str, int]
     :param export_copyright: Copyright, Legal rights and conditions for the model
     :type export_copyright: str
-    :param export_image_format: Images, Output format for images. PNG is lossless and generally preferred, but JPEG might be preferable for web applications due to the smaller file size * NAME Automatic, Determine the image format from the blender image name. * JPEG JPEG Format (.jpg), Encode and save textures as .jpg files. Be aware of a possible loss in quality. * PNG PNG Format (.png), Encode and save textures as .png files.
+    :param export_image_format: Images, Output format for images. PNG is lossless and generally preferred, but JPEG might be preferable for web applications due to the smaller file size * AUTO Automatic, Save PNGs as PNGs and JPEGs as JPEGs. If neither one, use PNG. * JPEG JPEG Format (.jpg), Save images as JPEGs. (Images that need alpha are saved as PNGs though.) Be aware of a possible loss in quality.
     :type export_image_format: typing.Union[str, int]
     :param export_texture_dir: Textures, Folder to place texture files in. Relative to the .gltf file
     :type export_texture_dir: str
@@ -215,6 +197,8 @@ def gltf(override_context: typing.Union[typing.
     :type export_cameras: bool
     :param export_selected: Selected Objects, Export selected objects only
     :type export_selected: bool
+    :param use_selection: Selected Objects, Export selected objects only
+    :type use_selection: bool
     :param export_extras: Custom Properties, Export custom properties as glTF extras
     :type export_extras: bool
     :param export_yup: +Y Up, Export using glTF convention, +Y up
@@ -229,9 +213,9 @@ def gltf(override_context: typing.Union[typing.
     :type export_frame_step: int
     :param export_force_sampling: Always Sample Animations, Apply sampling to all animations
     :type export_force_sampling: bool
-    :param export_nla_strips: NLA Strips, Export NLA Strip animations
+    :param export_nla_strips: Group by NLA Track, When on, multiple actions become part of the same glTF animation if they're pushed onto NLA tracks with the same name. When off, all the currently assigned actions become one glTF animation
     :type export_nla_strips: bool
-    :param export_def_bones: Export Deformation bones only, Export Deformation bones only (and needed bones for hierarchy)
+    :param export_def_bones: Export Deformation Bones Only, Export Deformation bones only (and needed bones for hierarchy)
     :type export_def_bones: bool
     :param export_current_frame: Use Current Frame, Export the scene in the current animation frame
     :type export_current_frame: bool
@@ -262,12 +246,7 @@ def gltf(override_context: typing.Union[typing.
     pass
 
 
-def obj(override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        filepath: str = "",
+def obj(filepath: str = "",
         check_existing: bool = True,
         filter_glob: str = "*.obj;*.mtl",
         use_selection: bool = False,
@@ -292,9 +271,6 @@ def obj(override_context: typing.Union[typing.
         axis_up: typing.Union[str, int] = 'Y'):
     ''' Save a Wavefront OBJ File
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Filepath used for exporting the file
     :type filepath: str
     :param check_existing: Check Existing, Check and warn on overwriting existing files
@@ -346,12 +322,7 @@ def obj(override_context: typing.Union[typing.
     pass
 
 
-def x3d(override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        filepath: str = "",
+def x3d(filepath: str = "",
         check_existing: bool = True,
         filter_glob: str = "*.x3d",
         use_selection: bool = False,
@@ -368,9 +339,6 @@ def x3d(override_context: typing.Union[typing.
         axis_up: typing.Union[str, int] = 'Y'):
     ''' Export selection to Extensible 3D file (.x3d)
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Filepath used for exporting the file
     :type filepath: str
     :param check_existing: Check Existing, Check and warn on overwriting existing files
