@@ -2,28 +2,21 @@ import sys
 import typing
 import bpy.types
 
-GenericType = typing.TypeVar("GenericType")
 
-
-def ply(override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        filepath: str = "",
-        files: bpy.types.
-        bpy_prop_collection['bpy.types.OperatorFileListElement'] = None,
+def ply(filepath: str = "",
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
+        hide_props_region: bool = True,
         directory: str = "",
         filter_glob: str = "*.ply"):
     ''' Load a PLY geometry file
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param files: File Path, File path used for importing the PLY file
-    :type files: bpy.types.bpy_prop_collection['bpy.types.OperatorFileListElement']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
+    :type hide_props_region: bool
     :param directory: directory
     :type directory: str
     :param filter_glob: filter_glob
@@ -33,15 +26,10 @@ def ply(override_context: typing.Union[typing.
     pass
 
 
-def stl(override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        filepath: str = "",
+def stl(filepath: str = "",
         filter_glob: str = "*.stl",
-        files: bpy.types.
-        bpy_prop_collection['bpy.types.OperatorFileListElement'] = None,
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
         directory: str = "",
         global_scale: float = 1.0,
         use_scene_unit: bool = False,
@@ -50,15 +38,12 @@ def stl(override_context: typing.Union[typing.
         axis_up: typing.Union[str, int] = 'Z'):
     ''' Load STL triangle mesh data
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param files: File Path
-    :type files: bpy.types.bpy_prop_collection['bpy.types.OperatorFileListElement']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param directory: directory
     :type directory: str
     :param global_scale: Scale
