@@ -2,19 +2,12 @@ import sys
 import typing
 import bpy.types
 
-GenericType = typing.TypeVar("GenericType")
 
-
-def fbx(override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        filepath: str = "",
+def fbx(filepath: str = "",
         directory: str = "",
         filter_glob: str = "*.fbx",
-        files: bpy.types.
-        bpy_prop_collection['bpy.types.OperatorFileListElement'] = None,
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
         ui_tab: typing.Union[str, int] = 'MAIN',
         use_manual_orientation: bool = False,
         global_scale: float = 1.0,
@@ -38,9 +31,6 @@ def fbx(override_context: typing.Union[typing.
         axis_up: typing.Union[str, int] = 'Y'):
     ''' Load a FBX file
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param directory: directory
@@ -48,7 +38,7 @@ def fbx(override_context: typing.Union[typing.
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param files: File Path
-    :type files: bpy.types.bpy_prop_collection['bpy.types.OperatorFileListElement']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param ui_tab: ui_tab, Import options categories * MAIN Main, Main basic settings. * ARMATURE Armatures, Armature-related settings.
     :type ui_tab: typing.Union[str, int]
     :param use_manual_orientation: Manual Orientation, Specify orientation and scale, instead of using embedded data in FBX file
@@ -96,46 +86,39 @@ def fbx(override_context: typing.Union[typing.
     pass
 
 
-def gltf(override_context: typing.Union[typing.
-                                        Dict, 'bpy.types.Context'] = None,
-         execution_context: typing.Union[str, int] = None,
-         undo: bool = None,
-         *,
-         filepath: str = "",
+def gltf(filepath: str = "",
          filter_glob: str = "*.glb;*.gltf",
-         files: bpy.types.
-         bpy_prop_collection['bpy.types.OperatorFileListElement'] = None,
+         files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                             'bpy_prop_collection'] = None,
          loglevel: int = 0,
          import_pack_images: bool = True,
-         import_shading: typing.Union[str, int] = 'NORMALS'):
+         import_shading: typing.Union[str, int] = 'NORMALS',
+         bone_heuristic: typing.Union[str, int] = 'TEMPERANCE',
+         guess_original_bind_pose: bool = True):
     ''' Load a glTF 2.0 file
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param files: File Path
-    :type files: bpy.types.bpy_prop_collection['bpy.types.OperatorFileListElement']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param loglevel: Log Level, Log Level
     :type loglevel: int
-    :param import_pack_images: Pack images, Pack all images into .blend file
+    :param import_pack_images: Pack Images, Pack all images into .blend file
     :type import_pack_images: bool
     :param import_shading: Shading, How normals are computed during import
     :type import_shading: typing.Union[str, int]
+    :param bone_heuristic: Bone Dir, Heuristic for placing bones. Tries to make bones pretty * BLENDER Blender (best for re-importing), Good for re-importing glTFs exported from Blender. Bone tips are placed on their local +Y axis (in glTF space). * TEMPERANCE Temperance (average), Decent all-around strategy. A bone with one child has its tip placed on the local axis closest to its child. * FORTUNE Fortune (may look better, less accurate), Might look better than Temperance, but also might have errors. A bone with one child has its tip placed at its child's root. Non-uniform scalings may get messed up though, so beware.
+    :type bone_heuristic: typing.Union[str, int]
+    :param guess_original_bind_pose: Guess Original Bind Pose, Try to guess the original bind pose for skinned meshes from the inverse bind matrices. When off, use default/rest pose as bind pose
+    :type guess_original_bind_pose: bool
     '''
 
     pass
 
 
-def obj(override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        filepath: str = "",
+def obj(filepath: str = "",
         filter_glob: str = "*.obj;*.mtl",
         use_edges: bool = True,
         use_smooth_groups: bool = True,
@@ -149,9 +132,6 @@ def obj(override_context: typing.Union[typing.
         axis_up: typing.Union[str, int] = 'Y'):
     ''' Load a Wavefront OBJ File
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param filter_glob: filter_glob
@@ -181,20 +161,12 @@ def obj(override_context: typing.Union[typing.
     pass
 
 
-def x3d(override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: bool = None,
-        *,
-        filepath: str = "",
+def x3d(filepath: str = "",
         filter_glob: str = "*.x3d;*.wrl",
         axis_forward: typing.Union[str, int] = 'Z',
         axis_up: typing.Union[str, int] = 'Y'):
     ''' Import an X3D or VRML2 file
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
     :param filter_glob: filter_glob
