@@ -450,7 +450,7 @@ def duplicate_move(MESH_OT_duplicate=None, TRANSFORM_OT_translate=None):
 
 
 def edge_collapse():
-    ''' Collapse selected edges
+    ''' Collapse isolated edges & faces regions, merging data such as UV's and vertex colors. This can collapse edge-rings as well as regions of connected faces into vertices
 
     '''
 
@@ -475,9 +475,11 @@ def edge_rotate(use_ccw: bool = False):
     pass
 
 
-def edge_split():
+def edge_split(type: typing.Union[str, int] = 'EDGE'):
     ''' Split selected edges so that each neighbor face gets its own copy
 
+    :param type: Type, Method to use for splitting * EDGE Faces by Edges, Split faces along selected edges. * VERT Faces & Edges by Vertices, Split faces & edges connected to selected vertices.
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -613,13 +615,17 @@ def extrude_region_shrink_fatten(MESH_OT_extrude_region=None,
     pass
 
 
-def extrude_repeat(offset: float = 2.0, steps: int = 10):
+def extrude_repeat(steps: int = 10,
+                   offset: typing.List[float] = (0.0, 0.0, 0.0),
+                   scale_offset: float = 1.0):
     ''' Extrude selected vertices, edges or faces repeatedly
 
-    :param offset: Offset
-    :type offset: float
     :param steps: Steps
     :type steps: int
+    :param offset: Offset, Offset vector
+    :type offset: typing.List[float]
+    :param scale_offset: Scale Offset
+    :type scale_offset: float
     '''
 
     pass
@@ -1135,7 +1141,7 @@ def polybuild_delete_at_cursor(
         use_proportional_projected: bool = False,
         release_confirm: bool = False,
         use_accurate: bool = False):
-    ''' Undocumented contribute <https://developer.blender.org/T51061>
+    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 
     :param mirror: Mirror Editing
     :type mirror: bool
@@ -1159,7 +1165,7 @@ def polybuild_delete_at_cursor(
 
 
 def polybuild_dissolve_at_cursor():
-    ''' Undocumented contribute <https://developer.blender.org/T51061>
+    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 
     '''
 
@@ -1170,7 +1176,7 @@ def polybuild_extrude_at_cursor_move(
         MESH_OT_polybuild_transform_at_cursor=None,
         MESH_OT_extrude_edges_indiv=None,
         TRANSFORM_OT_translate=None):
-    ''' Undocumented contribute <https://developer.blender.org/T51061>
+    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 
     :param MESH_OT_polybuild_transform_at_cursor: Poly Build Transform at Cursor
     :param MESH_OT_extrude_edges_indiv: Extrude Only Edges, Extrude individual edges only
@@ -1190,9 +1196,9 @@ def polybuild_face_at_cursor(
         use_proportional_projected: bool = False,
         release_confirm: bool = False,
         use_accurate: bool = False):
-    ''' Undocumented contribute <https://developer.blender.org/T51061>
+    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 
-    :param create_quads: Create quads, Automatically split edges in triangles to maintain quad topology
+    :param create_quads: Create Quads, Automatically split edges in triangles to maintain quad topology
     :type create_quads: bool
     :param mirror: Mirror Editing
     :type mirror: bool
@@ -1217,7 +1223,7 @@ def polybuild_face_at_cursor(
 
 def polybuild_face_at_cursor_move(MESH_OT_polybuild_face_at_cursor=None,
                                   TRANSFORM_OT_translate=None):
-    ''' Undocumented contribute <https://developer.blender.org/T51061>
+    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 
     :param MESH_OT_polybuild_face_at_cursor: Poly Build Face at Cursor
     :param TRANSFORM_OT_translate: Move, Move selected items
@@ -1235,7 +1241,7 @@ def polybuild_split_at_cursor(
         use_proportional_projected: bool = False,
         release_confirm: bool = False,
         use_accurate: bool = False):
-    ''' Undocumented contribute <https://developer.blender.org/T51061>
+    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 
     :param mirror: Mirror Editing
     :type mirror: bool
@@ -1260,7 +1266,7 @@ def polybuild_split_at_cursor(
 
 def polybuild_split_at_cursor_move(MESH_OT_polybuild_split_at_cursor=None,
                                    TRANSFORM_OT_translate=None):
-    ''' Undocumented contribute <https://developer.blender.org/T51061>
+    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 
     :param MESH_OT_polybuild_split_at_cursor: Poly Build Split at Cursor
     :param TRANSFORM_OT_translate: Move, Move selected items
@@ -1278,7 +1284,7 @@ def polybuild_transform_at_cursor(
         use_proportional_projected: bool = False,
         release_confirm: bool = False,
         use_accurate: bool = False):
-    ''' Undocumented contribute <https://developer.blender.org/T51061>
+    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 
     :param mirror: Mirror Editing
     :type mirror: bool
@@ -1304,7 +1310,7 @@ def polybuild_transform_at_cursor(
 def polybuild_transform_at_cursor_move(
         MESH_OT_polybuild_transform_at_cursor=None,
         TRANSFORM_OT_translate=None):
-    ''' Undocumented contribute <https://developer.blender.org/T51061>
+    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 
     :param MESH_OT_polybuild_transform_at_cursor: Poly Build Transform at Cursor
     :param TRANSFORM_OT_translate: Move, Move selected items
@@ -2129,8 +2135,8 @@ def shortest_path_select(edge_mode: typing.Union[str, int] = 'SELECT',
     pass
 
 
-def smoothen_normals(factor: float = 0.5):
-    ''' Smoothen custom normals based on adjacent vertex normals
+def smooth_normals(factor: float = 0.5):
+    ''' Smooth custom normals based on adjacent vertex normals
 
     :param factor: Factor, Specifies weight of smooth vs original normal
     :type factor: float
@@ -2169,7 +2175,7 @@ def sort_elements(
     pass
 
 
-def spin(steps: int = 9,
+def spin(steps: int = 12,
          dupli: bool = False,
          angle: float = 1.5708,
          use_auto_merge: bool = True,
