@@ -1,30 +1,16 @@
 import sys
 import typing
-import bpy.types
-
-GenericType = typing.TypeVar("GenericType")
 
 
-def bake_animation(override_context: typing.
-                   Union[typing.Dict, 'bpy.types.Context'] = None,
-                   execution_context: typing.Union[str, int] = None,
-                   undo: bool = None):
+def bake_animation():
     ''' Update the audio animation cache
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     '''
 
     pass
 
 
-def mixdown(override_context: typing.Union[typing.
-                                           Dict, 'bpy.types.Context'] = None,
-            execution_context: typing.Union[str, int] = None,
-            undo: bool = None,
-            *,
-            filepath: str = "",
+def mixdown(filepath: str = "",
             check_existing: bool = True,
             filter_blender: bool = False,
             filter_backup: bool = False,
@@ -39,6 +25,7 @@ def mixdown(override_context: typing.Union[typing.
             filter_collada: bool = False,
             filter_alembic: bool = False,
             filter_usd: bool = False,
+            filter_volume: bool = False,
             filter_folder: bool = True,
             filter_blenlib: bool = False,
             filemode: int = 9,
@@ -53,9 +40,6 @@ def mixdown(override_context: typing.Union[typing.
             split_channels: bool = False):
     ''' Mix the scene's audio to a sound file
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Path to file
     :type filepath: str
     :param check_existing: Check Existing, Check and warn on overwriting existing files
@@ -86,6 +70,8 @@ def mixdown(override_context: typing.Union[typing.
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_volume: Filter OpenVDB volume files
+    :type filter_volume: bool
     :param filter_folder: Filter folders
     :type filter_folder: bool
     :param filter_blenlib: Filter Blender IDs
@@ -115,12 +101,7 @@ def mixdown(override_context: typing.Union[typing.
     pass
 
 
-def open(override_context: typing.Union[typing.
-                                        Dict, 'bpy.types.Context'] = None,
-         execution_context: typing.Union[str, int] = None,
-         undo: bool = None,
-         *,
-         filepath: str = "",
+def open(filepath: str = "",
          hide_props_region: bool = True,
          filter_blender: bool = False,
          filter_backup: bool = False,
@@ -135,6 +116,7 @@ def open(override_context: typing.Union[typing.
          filter_collada: bool = False,
          filter_alembic: bool = False,
          filter_usd: bool = False,
+         filter_volume: bool = False,
          filter_folder: bool = True,
          filter_blenlib: bool = False,
          filemode: int = 9,
@@ -147,9 +129,6 @@ def open(override_context: typing.Union[typing.
          mono: bool = False):
     ''' Load a sound file
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Path to file
     :type filepath: str
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
@@ -180,6 +159,8 @@ def open(override_context: typing.Union[typing.
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_volume: Filter OpenVDB volume files
+    :type filter_volume: bool
     :param filter_folder: Filter folders
     :type filter_folder: bool
     :param filter_blenlib: Filter Blender IDs
@@ -205,12 +186,7 @@ def open(override_context: typing.Union[typing.
     pass
 
 
-def open_mono(override_context: typing.Union[typing.
-                                             Dict, 'bpy.types.Context'] = None,
-              execution_context: typing.Union[str, int] = None,
-              undo: bool = None,
-              *,
-              filepath: str = "",
+def open_mono(filepath: str = "",
               hide_props_region: bool = True,
               filter_blender: bool = False,
               filter_backup: bool = False,
@@ -225,6 +201,7 @@ def open_mono(override_context: typing.Union[typing.
               filter_collada: bool = False,
               filter_alembic: bool = False,
               filter_usd: bool = False,
+              filter_volume: bool = False,
               filter_folder: bool = True,
               filter_blenlib: bool = False,
               filemode: int = 9,
@@ -237,9 +214,6 @@ def open_mono(override_context: typing.Union[typing.
               mono: bool = True):
     ''' Load a sound file as mono
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param filepath: File Path, Path to file
     :type filepath: str
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
@@ -270,6 +244,8 @@ def open_mono(override_context: typing.Union[typing.
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_volume: Filter OpenVDB volume files
+    :type filter_volume: bool
     :param filter_folder: Filter folders
     :type filter_folder: bool
     :param filter_blenlib: Filter Blender IDs
@@ -295,32 +271,17 @@ def open_mono(override_context: typing.Union[typing.
     pass
 
 
-def pack(override_context: typing.Union[typing.
-                                        Dict, 'bpy.types.Context'] = None,
-         execution_context: typing.Union[str, int] = None,
-         undo: bool = None):
+def pack():
     ''' Pack the sound into the current blend file
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     '''
 
     pass
 
 
-def unpack(override_context: typing.Union[typing.
-                                          Dict, 'bpy.types.Context'] = None,
-           execution_context: typing.Union[str, int] = None,
-           undo: bool = None,
-           *,
-           method: typing.Union[str, int] = 'USE_LOCAL',
-           id: str = ""):
+def unpack(method: typing.Union[str, int] = 'USE_LOCAL', id: str = ""):
     ''' Unpack the sound to the samples filename
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     :param method: Method, How to unpack
     :type method: typing.Union[str, int]
     :param id: Sound Name, Sound data-block name to unpack
@@ -330,15 +291,9 @@ def unpack(override_context: typing.Union[typing.
     pass
 
 
-def update_animation_flags(override_context: typing.
-                           Union[typing.Dict, 'bpy.types.Context'] = None,
-                           execution_context: typing.Union[str, int] = None,
-                           undo: bool = None):
+def update_animation_flags():
     ''' Update animation flags
 
-    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
-    :type execution_context: typing.Union[str, int]
-    :type undo: bool
     '''
 
     pass
