@@ -5,7 +5,6 @@ import bl_operators.wm
 
 
 def alembic_export(filepath: str = "",
-                   hide_props_region: bool = True,
                    check_existing: bool = True,
                    filter_blender: bool = False,
                    filter_backup: bool = False,
@@ -20,6 +19,7 @@ def alembic_export(filepath: str = "",
                    filter_collada: bool = False,
                    filter_alembic: bool = True,
                    filter_usd: bool = False,
+                   filter_volume: bool = False,
                    filter_folder: bool = True,
                    filter_blenlib: bool = False,
                    filemode: int = 8,
@@ -56,8 +56,6 @@ def alembic_export(filepath: str = "",
 
     :param filepath: File Path, Path to file
     :type filepath: str
-    :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
-    :type hide_props_region: bool
     :param check_existing: Check Existing, Check and warn on overwriting existing files
     :type check_existing: bool
     :param filter_blender: Filter .blend files
@@ -86,6 +84,8 @@ def alembic_export(filepath: str = "",
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_volume: Filter OpenVDB volume files
+    :type filter_volume: bool
     :param filter_folder: Filter folders
     :type filter_folder: bool
     :param filter_blenlib: Filter Blender IDs
@@ -155,7 +155,6 @@ def alembic_export(filepath: str = "",
 
 
 def alembic_import(filepath: str = "",
-                   hide_props_region: bool = True,
                    check_existing: bool = True,
                    filter_blender: bool = False,
                    filter_backup: bool = False,
@@ -170,6 +169,7 @@ def alembic_import(filepath: str = "",
                    filter_collada: bool = False,
                    filter_alembic: bool = True,
                    filter_usd: bool = False,
+                   filter_volume: bool = False,
                    filter_folder: bool = True,
                    filter_blenlib: bool = False,
                    filemode: int = 8,
@@ -185,8 +185,6 @@ def alembic_import(filepath: str = "",
 
     :param filepath: File Path, Path to file
     :type filepath: str
-    :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
-    :type hide_props_region: bool
     :param check_existing: Check Existing, Check and warn on overwriting existing files
     :type check_existing: bool
     :param filter_blender: Filter .blend files
@@ -215,6 +213,8 @@ def alembic_import(filepath: str = "",
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_volume: Filter OpenVDB volume files
+    :type filter_volume: bool
     :param filter_folder: Filter folders
     :type filter_folder: bool
     :param filter_blenlib: Filter Blender IDs
@@ -242,37 +242,37 @@ def alembic_import(filepath: str = "",
     pass
 
 
-def append(filepath: str = "",
-           directory: str = "",
-           filename: str = "",
-           files: typing.
-           Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
-                 List['bpy.types.OperatorFileListElement'],
-                 'bpy_prop_collection'] = None,
-           filter_blender: bool = True,
-           filter_backup: bool = False,
-           filter_image: bool = False,
-           filter_movie: bool = False,
-           filter_python: bool = False,
-           filter_font: bool = False,
-           filter_sound: bool = False,
-           filter_text: bool = False,
-           filter_archive: bool = False,
-           filter_btx: bool = False,
-           filter_collada: bool = False,
-           filter_alembic: bool = False,
-           filter_usd: bool = False,
-           filter_folder: bool = True,
-           filter_blenlib: bool = True,
-           filemode: int = 1,
-           display_type: typing.Union[str, int] = 'DEFAULT',
-           sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
-           link: bool = False,
-           autoselect: bool = True,
-           active_collection: bool = True,
-           instance_collections: bool = False,
-           set_fake: bool = False,
-           use_recursive: bool = True):
+def append(
+        filepath: str = "",
+        directory: str = "",
+        filename: str = "",
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
+        filter_blender: bool = True,
+        filter_backup: bool = False,
+        filter_image: bool = False,
+        filter_movie: bool = False,
+        filter_python: bool = False,
+        filter_font: bool = False,
+        filter_sound: bool = False,
+        filter_text: bool = False,
+        filter_archive: bool = False,
+        filter_btx: bool = False,
+        filter_collada: bool = False,
+        filter_alembic: bool = False,
+        filter_usd: bool = False,
+        filter_volume: bool = False,
+        filter_folder: bool = True,
+        filter_blenlib: bool = True,
+        filemode: int = 1,
+        display_type: typing.Union[str, int] = 'DEFAULT',
+        sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
+        link: bool = False,
+        autoselect: bool = True,
+        active_collection: bool = True,
+        instance_collections: bool = False,
+        set_fake: bool = False,
+        use_recursive: bool = True):
     ''' Append from a Library .blend file
 
     :param filepath: File Path, Path to file
@@ -282,7 +282,7 @@ def append(filepath: str = "",
     :param filename: File Name, Name of the file
     :type filename: str
     :param files: Files
-    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -309,6 +309,8 @@ def append(filepath: str = "",
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_volume: Filter OpenVDB volume files
+    :type filter_volume: bool
     :param filter_folder: Filter folders
     :type filter_folder: bool
     :param filter_blenlib: Filter Blender IDs
@@ -339,18 +341,16 @@ def append(filepath: str = "",
 def batch_rename(
         data_type: typing.Union[str, int] = 'OBJECT',
         data_source: typing.Union[str, int] = 'SELECT',
-        actions: typing.
-        Union[typing.Dict[str, 'bl_operators.wm.BatchRenameAction'], typing.
-              List['bl_operators.wm.BatchRenameAction'],
-              'bpy_prop_collection'] = None):
-    ''' Undocumented contribute <https://developer.blender.org/T51061>
+        actions: typing.Union[typing.List['bl_operators.wm.BatchRenameAction'],
+                              'bpy_prop_collection'] = None):
+    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 
     :param data_type: Type, Type of data to rename
     :type data_type: typing.Union[str, int]
     :param data_source: Source
     :type data_source: typing.Union[str, int]
     :param actions: actions
-    :type actions: typing.Union[typing.Dict[str, 'bl_operators.wm.BatchRenameAction'], typing.List['bl_operators.wm.BatchRenameAction'], 'bpy_prop_collection']
+    :type actions: typing.Union[typing.List['bl_operators.wm.BatchRenameAction'], 'bpy_prop_collection']
     '''
 
     pass
@@ -398,7 +398,6 @@ def call_panel(name: str = "", keep_open: bool = True):
 
 def collada_export(
         filepath: str = "",
-        hide_props_region: bool = True,
         check_existing: bool = True,
         filter_blender: bool = False,
         filter_backup: bool = False,
@@ -413,6 +412,7 @@ def collada_export(
         filter_collada: bool = True,
         filter_alembic: bool = False,
         filter_usd: bool = False,
+        filter_volume: bool = False,
         filter_folder: bool = True,
         filter_blenlib: bool = False,
         filemode: int = 8,
@@ -456,8 +456,6 @@ def collada_export(
 
     :param filepath: File Path, Path to file
     :type filepath: str
-    :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
-    :type hide_props_region: bool
     :param check_existing: Check Existing, Check and warn on overwriting existing files
     :type check_existing: bool
     :param filter_blender: Filter .blend files
@@ -486,6 +484,8 @@ def collada_export(
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_volume: Filter OpenVDB volume files
+    :type filter_volume: bool
     :param filter_folder: Filter folders
     :type filter_folder: bool
     :param filter_blenlib: Filter Blender IDs
@@ -566,7 +566,6 @@ def collada_export(
 
 
 def collada_import(filepath: str = "",
-                   hide_props_region: bool = True,
                    filter_blender: bool = False,
                    filter_backup: bool = False,
                    filter_image: bool = False,
@@ -580,6 +579,7 @@ def collada_import(filepath: str = "",
                    filter_collada: bool = True,
                    filter_alembic: bool = False,
                    filter_usd: bool = False,
+                   filter_volume: bool = False,
                    filter_folder: bool = True,
                    filter_blenlib: bool = False,
                    filemode: int = 8,
@@ -595,8 +595,6 @@ def collada_import(filepath: str = "",
 
     :param filepath: File Path, Path to file
     :type filepath: str
-    :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
-    :type hide_props_region: bool
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -623,6 +621,8 @@ def collada_import(filepath: str = "",
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_volume: Filter OpenVDB volume files
+    :type filter_volume: bool
     :param filter_folder: Filter folders
     :type filter_folder: bool
     :param filter_blenlib: Filter Blender IDs
@@ -711,7 +711,7 @@ def context_cycle_int(data_path: str = "",
 
 
 def context_menu_enum(data_path: str = ""):
-    ''' Undocumented contribute <https://developer.blender.org/T51061>
+    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 
     :param data_path: Context Attributes, RNA context string
     :type data_path: str
@@ -746,7 +746,7 @@ def context_modal_mouse(data_path_iter: str = "",
 
 
 def context_pie_enum(data_path: str = ""):
-    ''' Undocumented contribute <https://developer.blender.org/T51061>
+    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 
     :param data_path: Context Attributes, RNA context string
     :type data_path: str
@@ -942,7 +942,7 @@ def doc_view_manual_ui_context():
 
 
 def drop_blend_file(filepath: str = ""):
-    ''' Undocumented contribute <https://developer.blender.org/T51061>
+    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 
     :param filepath: filepath
     :type filepath: str
@@ -1001,6 +1001,7 @@ def lib_reload(library: str = "",
                filter_collada: bool = False,
                filter_alembic: bool = False,
                filter_usd: bool = False,
+               filter_volume: bool = False,
                filter_folder: bool = True,
                filter_blenlib: bool = False,
                filemode: int = 8,
@@ -1045,6 +1046,8 @@ def lib_reload(library: str = "",
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_volume: Filter OpenVDB volume files
+    :type filter_volume: bool
     :param filter_folder: Filter folders
     :type filter_folder: bool
     :param filter_blenlib: Filter Blender IDs
@@ -1067,10 +1070,8 @@ def lib_relocate(
         filepath: str = "",
         directory: str = "",
         filename: str = "",
-        files: typing.
-        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
-              List['bpy.types.OperatorFileListElement'],
-              'bpy_prop_collection'] = None,
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
         hide_props_region: bool = True,
         filter_blender: bool = True,
         filter_backup: bool = False,
@@ -1085,6 +1086,7 @@ def lib_relocate(
         filter_collada: bool = False,
         filter_alembic: bool = False,
         filter_usd: bool = False,
+        filter_volume: bool = False,
         filter_folder: bool = True,
         filter_blenlib: bool = False,
         filemode: int = 8,
@@ -1102,7 +1104,7 @@ def lib_relocate(
     :param filename: File Name, Name of the file
     :type filename: str
     :param files: Files
-    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
     :type hide_props_region: bool
     :param filter_blender: Filter .blend files
@@ -1131,6 +1133,8 @@ def lib_relocate(
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_volume: Filter OpenVDB volume files
+    :type filter_volume: bool
     :param filter_folder: Filter folders
     :type filter_folder: bool
     :param filter_blenlib: Filter Blender IDs
@@ -1151,10 +1155,8 @@ def lib_relocate(
 def link(filepath: str = "",
          directory: str = "",
          filename: str = "",
-         files: typing.
-         Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
-               List['bpy.types.OperatorFileListElement'],
-               'bpy_prop_collection'] = None,
+         files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                             'bpy_prop_collection'] = None,
          filter_blender: bool = True,
          filter_backup: bool = False,
          filter_image: bool = False,
@@ -1168,6 +1170,7 @@ def link(filepath: str = "",
          filter_collada: bool = False,
          filter_alembic: bool = False,
          filter_usd: bool = False,
+         filter_volume: bool = False,
          filter_folder: bool = True,
          filter_blenlib: bool = True,
          filemode: int = 1,
@@ -1187,7 +1190,7 @@ def link(filepath: str = "",
     :param filename: File Name, Name of the file
     :type filename: str
     :param files: Files
-    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -1214,6 +1217,8 @@ def link(filepath: str = "",
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_volume: Filter OpenVDB volume files
+    :type filter_volume: bool
     :param filter_folder: Filter folders
     :type filter_folder: bool
     :param filter_blenlib: Filter Blender IDs
@@ -1262,6 +1267,7 @@ def open_mainfile(filepath: str = "",
                   filter_collada: bool = False,
                   filter_alembic: bool = False,
                   filter_usd: bool = False,
+                  filter_volume: bool = False,
                   filter_folder: bool = True,
                   filter_blenlib: bool = False,
                   filemode: int = 8,
@@ -1303,6 +1309,8 @@ def open_mainfile(filepath: str = "",
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_volume: Filter OpenVDB volume files
+    :type filter_volume: bool
     :param filter_folder: Filter folders
     :type filter_folder: bool
     :param filter_blenlib: Filter Blender IDs
@@ -1327,7 +1335,7 @@ def open_mainfile(filepath: str = "",
 
 
 def operator_cheat_sheet():
-    ''' List all the Operators in a text-block, useful for scripting :file: startup/bl_operators/wm.py\:1578 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/wm.py$1578> _
+    ''' List all the Operators in a text-block, useful for scripting :file: startup/bl_operators/wm.py\:1586 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/wm.py$1586> _
 
     '''
 
@@ -1343,7 +1351,7 @@ def operator_defaults():
 
 
 def operator_pie_enum(data_path: str = "", prop_string: str = ""):
-    ''' Undocumented contribute <https://developer.blender.org/T51061>
+    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
 
     :param data_path: Operator, Operator name (in python as string)
     :type data_path: str
@@ -1404,10 +1412,8 @@ def path_open(filepath: str = ""):
 
 
 def previews_batch_clear(
-        files: typing.
-        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
-              List['bpy.types.OperatorFileListElement'],
-              'bpy_prop_collection'] = None,
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
         directory: str = "",
         filter_blender: bool = True,
         filter_folder: bool = True,
@@ -1420,7 +1426,7 @@ def previews_batch_clear(
     ''' Clear selected .blend file's previews
 
     :param files: files
-    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param directory: directory
     :type directory: str
     :param filter_blender: filter_blender
@@ -1445,10 +1451,8 @@ def previews_batch_clear(
 
 
 def previews_batch_generate(
-        files: typing.
-        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
-              List['bpy.types.OperatorFileListElement'],
-              'bpy_prop_collection'] = None,
+        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
+                            'bpy_prop_collection'] = None,
         directory: str = "",
         filter_blender: bool = True,
         filter_folder: bool = True,
@@ -1461,7 +1465,7 @@ def previews_batch_generate(
     ''' Generate selected .blend file's previews
 
     :param files: files
-    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param directory: directory
     :type directory: str
     :param filter_blender: filter_blender
@@ -1486,13 +1490,10 @@ def previews_batch_generate(
 
 
 def previews_clear(
-        id_type: typing.Union[typing.Set[str], typing.Set[int]] = {
-            'ALL', 'GEOMETRY', 'GROUP', 'IMAGE', 'LIGHT', 'MATERIAL', 'OBJECT',
-            'SCENE', 'SHADING', 'TEXTURE', 'WORLD'
-        }):
+        id_type: typing.Union[typing.Set[str], typing.Set[int]] = {}):
     ''' Clear data-block previews (only for some types like objects, materials, textures, etc.)
 
-    :param id_type: Data-Block Type, Which data-block previews to clear * ALL All Types. * GEOMETRY All Geometry Types, Clear previews for scenes, collections and objects. * SHADING All Shading Types, Clear previews for materiasl, lights, worlds, textures and images. * SCENE Scenes. * GROUP Groups. * OBJECT Objects. * MATERIAL Materials. * LIGHT Lights. * WORLD Worlds. * TEXTURE Textures. * IMAGE Images.
+    :param id_type: Data-Block Type, Which data-block previews to clear * ALL All Types. * GEOMETRY All Geometry Types, Clear previews for scenes, collections and objects. * SHADING All Shading Types, Clear previews for materials, lights, worlds, textures and images. * SCENE Scenes. * COLLECTION Collections. * OBJECT Objects. * MATERIAL Materials. * LIGHT Lights. * WORLD Worlds. * TEXTURE Textures. * IMAGE Images.
     :type id_type: typing.Union[typing.Set[str], typing.Set[int]]
     '''
 
@@ -1508,7 +1509,7 @@ def previews_ensure():
 
 
 def properties_add(data_path: str = ""):
-    ''' Undocumented contribute <https://developer.blender.org/T51061>
+    ''' Add your own property to the data-block
 
     :param data_path: Property Edit, Property data_path edit
     :type data_path: str
@@ -1539,7 +1540,7 @@ def properties_edit(data_path: str = "",
                     soft_max: float = 10000.0,
                     description: str = "",
                     subtype: typing.Union[str, int] = ''):
-    ''' Undocumented contribute <https://developer.blender.org/T51061>
+    ''' Edit the attributes of the property
 
     :param data_path: Property Edit, Property data_path edit
     :type data_path: str
@@ -1549,17 +1550,17 @@ def properties_edit(data_path: str = "",
     :type value: str
     :param default: Default Value, Default value of the property. Important for NLA mixing
     :type default: str
-    :param min: Min
+    :param min: Min, Minimum value of the property
     :type min: float
-    :param max: Max
+    :param max: Max, Maximum value of the property
     :type max: float
-    :param use_soft_limits: Use Soft Limits
+    :param use_soft_limits: Use Soft Limits, Limits the Property Value slider to a range, values outside the range must be inputted numerically
     :type use_soft_limits: bool
-    :param is_overridable_library: Is Library Overridable
+    :param is_overridable_library: Is Library Overridable, Allow the property to be overridden when the Data-Block is linked
     :type is_overridable_library: bool
-    :param soft_min: Min
+    :param soft_min: Min, Minimum value of the property
     :type soft_min: float
-    :param soft_max: Max
+    :param soft_max: Max, Maximum value of the property
     :type soft_max: float
     :param description: Tooltip
     :type description: str
@@ -1702,6 +1703,7 @@ def recover_auto_save(filepath: str = "",
                       filter_collada: bool = False,
                       filter_alembic: bool = False,
                       filter_usd: bool = False,
+                      filter_volume: bool = False,
                       filter_folder: bool = False,
                       filter_blenlib: bool = False,
                       filemode: int = 8,
@@ -1739,6 +1741,8 @@ def recover_auto_save(filepath: str = "",
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_volume: Filter OpenVDB volume files
+    :type filter_volume: bool
     :param filter_folder: Filter folders
     :type filter_folder: bool
     :param filter_blenlib: Filter Blender IDs
@@ -1804,6 +1808,7 @@ def save_as_mainfile(filepath: str = "",
                      filter_collada: bool = False,
                      filter_alembic: bool = False,
                      filter_usd: bool = False,
+                     filter_volume: bool = False,
                      filter_folder: bool = True,
                      filter_blenlib: bool = False,
                      filemode: int = 8,
@@ -1846,6 +1851,8 @@ def save_as_mainfile(filepath: str = "",
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_volume: Filter OpenVDB volume files
+    :type filter_volume: bool
     :param filter_folder: Filter folders
     :type filter_folder: bool
     :param filter_blenlib: Filter Blender IDs
@@ -1858,7 +1865,7 @@ def save_as_mainfile(filepath: str = "",
     :type sort_method: typing.Union[str, int]
     :param compress: Compress, Write compressed .blend file
     :type compress: bool
-    :param relative_remap: Remap Relative, Make paths relative when saving to a different directory
+    :param relative_remap: Remap Relative, Remap relative paths when saving to a different directory
     :type relative_remap: bool
     :param copy: Save Copy, Save a copy of the actual working state but does not make saved file active
     :type copy: bool
@@ -1891,6 +1898,7 @@ def save_mainfile(filepath: str = "",
                   filter_collada: bool = False,
                   filter_alembic: bool = False,
                   filter_usd: bool = False,
+                  filter_volume: bool = False,
                   filter_folder: bool = True,
                   filter_blenlib: bool = False,
                   filemode: int = 8,
@@ -1933,6 +1941,8 @@ def save_mainfile(filepath: str = "",
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_volume: Filter OpenVDB volume files
+    :type filter_volume: bool
     :param filter_folder: Filter folders
     :type filter_folder: bool
     :param filter_blenlib: Filter Blender IDs
@@ -1945,7 +1955,7 @@ def save_mainfile(filepath: str = "",
     :type sort_method: typing.Union[str, int]
     :param compress: Compress, Write compressed .blend file
     :type compress: bool
-    :param relative_remap: Remap Relative, Make paths relative when saving to a different directory
+    :param relative_remap: Remap Relative, Remap relative paths when saving to a different directory
     :type relative_remap: bool
     :param exit: Exit, Exit Blender after saving
     :type exit: bool
@@ -1962,9 +1972,11 @@ def save_userpref():
     pass
 
 
-def search_menu():
+def search_menu(type: typing.Union[str, int] = 'OPERATOR'):
     ''' Pop-up a search menu over all available operators in current context
 
+    :param type: Type * OPERATOR Operator, Search all operators. * MENU Menu, Search active menu items.
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -2052,7 +2064,7 @@ def tool_set_by_index(index: int = 0,
 
 
 def toolbar():
-    ''' Undocumented contribute <https://developer.blender.org/T51061> :file: startup/bl_operators/wm.py\:1782 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/wm.py$1782> _
+    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __. :file: startup/bl_operators/wm.py\:1790 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/wm.py$1790> _
 
     '''
 
@@ -2060,7 +2072,7 @@ def toolbar():
 
 
 def toolbar_fallback_pie():
-    ''' Undocumented contribute <https://developer.blender.org/T51061> :file: startup/bl_operators/wm.py\:1806 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/wm.py$1806> _
+    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __. :file: startup/bl_operators/wm.py\:1814 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/wm.py$1814> _
 
     '''
 
@@ -2068,7 +2080,7 @@ def toolbar_fallback_pie():
 
 
 def toolbar_prompt():
-    ''' Leader key like functionality for accessing tools :file: startup/bl_operators/wm.py\:1906 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/wm.py$1906> _
+    ''' Leader key like functionality for accessing tools :file: startup/bl_operators/wm.py\:1914 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/wm.py$1914> _
 
     '''
 
@@ -2112,6 +2124,7 @@ def usd_export(filepath: str = "",
                filter_collada: bool = False,
                filter_alembic: bool = False,
                filter_usd: bool = True,
+               filter_volume: bool = False,
                filter_folder: bool = True,
                filter_blenlib: bool = False,
                filemode: int = 8,
@@ -2157,6 +2170,8 @@ def usd_export(filepath: str = "",
     :type filter_alembic: bool
     :param filter_usd: Filter USD files
     :type filter_usd: bool
+    :param filter_volume: Filter OpenVDB volume files
+    :type filter_volume: bool
     :param filter_folder: Filter folders
     :type filter_folder: bool
     :param filter_blenlib: Filter Blender IDs
@@ -2236,3 +2251,11 @@ def window_new_main():
     '''
 
     pass
+
+
+def xr_session_toggle():
+    ''' Open a view for use with virtual reality headsets, or close it if already opened
+
+    '''
+
+    pass
